@@ -1,9 +1,9 @@
 //! This module contains various enums used for network classification.
 
-/// `NetworkModel` decides the algorithm used to connect the nodes during `Network`'s
+/// `Model` decides the algorithm used to connect the nodes during `Network`'s
 /// initialization.
 #[derive(Debug, Clone)]
-pub enum NetworkModel {
+pub enum Model {
     /// The Erdos–Renyi random network model.
     ER {
         /// The probability of connecting any given pair of nodes.
@@ -24,13 +24,20 @@ pub enum NetworkModel {
     None,
 }
 
-/// `LinkWeight` determines the weight (ie. the probability of infection) of each link in the
-/// network.
+/// `Weight` determines the weight of each link in the network (ie. the probability of the
+/// infection spreading through it in each time step).
 #[derive(Debug, Clone)]
-pub enum LinkWeight {
+pub enum Weight {
     /// The probability should be constant end equalt to `c`. Keep in mind that 0 < c <= 1, the
-    /// `Network` constructor **will panic** if that is not the case.
+    /// `Network::new()` constructor **will panic** if that is not the case.
     Constant { c: f64 },
     /// A weight sampled uniformly from (0, 1).
     Uniform,
 }
+
+/// `Error` is used to signify a recoverable error.
+#[derive(Debug, PartialEq)]
+pub enum Error {
+    NoSuchNode { idx: usize },
+    BadWeight { weight: f64 },
+}
